import React, { useState, useEffect } from 'react';
import Button from '@mui/material/Button';
import TextField from '@mui/material/TextField';
import yzs from "./business/request.js";
import styles from './LoginPage.module.css';
import { useSelector, useDispatch } from 'react-redux'
import { setAddress } from "./business/ipSlice.js"
import { setFlushToken, setAccessToken, setUserInfo, selectFlushToken } from "./business/userSlice.js"
import logo from './assets/logo.png'; // Tell webpack this JS file uses this image
import { Container, Tab, Box } from '@mui/material';
import TabPanel from '@mui/lab/TabPanel';
import { TabList } from '@mui/lab';
import TabContext from '@mui/lab/TabContext';
import DynamicCodeForm from './components/DynamicCodeForm.js';
import PasswordForm from './components/PasswordForm.js';

import { createTheme, ThemeProvider } from '@mui/material/styles';

const theme = createTheme({
    status: {
        danger: '#e53e3e',
    },
    palette: {
        primary: {
            main: '#FF595A',
            darker: '#FF595A',
        },
        neutral: {
            main: '#64748B',
            contrastText: '#fff',
        },
    },
});

export default function () {
    const [value, setValue] = useState("1");
    const [username, setUsername] = useState('');
    const [password, setPassword] = useState('');

    const handleChange = (event, newValue) => {
        setValue(newValue);
    };


    const ip = useSelector(state => state.ip.value)
    const flushToken = useSelector(selectFlushToken)
    const dispatch = useDispatch()

    const getIp = async () => {
        // Connect ipapi.co with fetch()
        const response = await fetch("https://ipapi.co/json/")
        const data = await response.json()
        // Set the IP address to the constant `ip`
        dispatch(setAddress(data.ip));
    }

    // Run `getIP` function above just once when the page is rendered
    useEffect(() => {
        getIp()
    }, [])



    const handleInputChange = (event) => {
        const { name, value } = event.target;
        if (name === 'username') setUsername(value);
        if (name === 'password') setPassword(value);
    };

    const handleSubmit = (event) => {
        event.preventDefault();
        console.log(`Username: ${username}\nPassword: ${password}  ip: ${ip}`);

        yzs.login(ip.payload).then(token => {
            dispatch(setFlushToken(token));
            yzs.get_access_token(ip.payload, token).then(token => {
                // yzs.update_access_token(ip.payload, token);
                dispatch(setAccessToken(token));
                yzs.get_user_info(ip.payload, token).then(info => {
                    dispatch(setUserInfo(info));
                    let passportId = info.passportId;
                    yzs.user_select(ip.payload, token).then(info => {
                        yzs.get_record_list(token, passportId)
                    })

                });
            })
        });


    };

    return (
        <div className={styles.loginPage}>
            <div className={styles.title}>
                <img className={styles.titleIcon} src={logo} />
                <h1 className={styles.titleText}>纽曼AI语记</h1>
            </div>

            <div className={styles.loginFrame}>
                <ThemeProvider theme={theme}>
                    <Container component="form" className={styles.form} onSubmit={handleSubmit}
                        sx={{
                            width: 360,
                            height: 418,
                            backgroundColor: 'white',
                            display: "flex",
                            flexDirection: "column",
                            justifyContent: "center",
                            alignItems: "center",
                            boxShadow: "0px 5px 20px 0px rgba(146,0,1,0.1)",
                            borderRadius: 4,

                        }}
                    >
                        <TabContext value={value}>
                            <Box>

                                <TabList

                                    aria-label="basic tabs example" value={value} onChange={handleChange} >
                                    <Tab label="手机动态码登录" value="1" />
                                    <Tab label="账号密码登录" value="2" />
                                </TabList>
                            </Box>

                            <TabPanel value="1" >
                                <DynamicCodeForm />
                            </TabPanel>
                            <TabPanel value="2" >
                                <PasswordForm />
                            </TabPanel>
                        </TabContext>



                    </Container>
                </ThemeProvider >
            </div>


        </div>
    );
}