import { createSlice } from '@reduxjs/toolkit'

export const userSlice = createSlice({
    name: 'user',
    initialState: {
        flushToken: "",
        accessToken: "",
        info: {},
    },
    reducers: {
        setFlushToken: (state, token) => {
            // Redux Toolkit allows us to write "mutating" logic in reducers. It
            // doesn't actually mutate the state because it uses the Immer library,
            // which detects changes to a "draft state" and produces a brand new
            // immutable state based off those changes
            state.flushToken = token;
        },
        setAccessToken: (state, token) => {
            state.accessToken = token;
        },
        setUserInfo: (state, info) => {
            state.info = info;
            // state.createTime = info.createTime;
            // state.userName = info.userName;
        },
    }
})

// Action creators are generated for each case reducer function
export const { setFlushToken, setAccessToken, setUserInfo } = userSlice.actions
export const selectFlushToken = (state) => state.user.flushToken

export default userSlice.reducer